@@ -26,21 +26,21 @@ extern void xmlCheckVersion(int version);
  *
  * the version string like "1.2.3"
  */
-#define LIBXML_DOTTED_VERSION "2.4.15"
+#define LIBXML_DOTTED_VERSION "2.4.19"
 
 /**
  * LIBXML_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXML_VERSION 20415
+#define LIBXML_VERSION 20419
 
 /**
  * LIBXML_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXML_VERSION_STRING "20415"
+#define LIBXML_VERSION_STRING "20419"
 
 /**
  * LIBXML_TEST_VERSION:
@@ -48,7 +48,7 @@ extern void xmlCheckVersion(int version);
  * Macro to check that the libxml version in use is compatible with
  * the version the software has been compiled against
  */
-#define LIBXML_TEST_VERSION xmlCheckVersion(20415);
+#define LIBXML_TEST_VERSION xmlCheckVersion(20419);
 
 #ifndef VMS
 #if 0
@@ -108,6 +108,15 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_HTML_ENABLED
 #endif
 
+/**
+ * LIBXML_C14N_ENABLED:
+ *
+ * Whether the Canonicalization support is configured in
+ */
+#if 1
+#define LIBXML_C14N_ENABLED
+#endif
+
 /**
  * LIBXML_CATALOG_ENABLED:
  *
@@ -158,11 +167,9 @@ extern void xmlCheckVersion(int version);
  *
  * Whether iconv support is available
  */
-#if !defined(WIN32) || defined(__CYGWIN__)
 #if 1
 #define LIBXML_ICONV_ENABLED
 #endif
-#endif
 
 /**
  * LIBXML_DEBUG_ENABLED:
