@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * $Id: trionan.h,v 1.1 2001/08/21 10:56:29 veillard Exp $
+ * $Id: trionan.h,v 1.2 2002/01/19 15:40:18 breese Exp $
  *
  * Copyright (C) 2001 Bjorn Reese <breese@users.sourceforge.net>
  *
@@ -15,50 +15,42 @@
  *
  ************************************************************************/
 
-#ifndef __TRIO_NAN_H__
-#define __TRIO_NAN_H__
+#ifndef TRIO_NAN_H
+#define TRIO_NAN_H
+
+#include "triodef.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
-
-#ifndef TRIO_PUBLIC
-#define TRIO_PUBLIC
-#endif
-
 /*
  * Return NaN (Not-a-Number).
  */
-TRIO_PUBLIC
-double trio_nan(void);
+TRIO_PUBLIC double trio_nan(void);
 
 /*
  * Return positive infinity.
  */
-TRIO_PUBLIC
-double trio_pinf(void);
+TRIO_PUBLIC double trio_pinf(void);
 
 /*
  * Return negative infinity.
  */
-TRIO_PUBLIC
-double trio_ninf(void);
+TRIO_PUBLIC double trio_ninf(void);
   
 /*
  * If number is a NaN return non-zero, otherwise return zero.
  */
-TRIO_PUBLIC
-int trio_isnan(double number);
+TRIO_PUBLIC int trio_isnan(double number);
 
 /*
  * If number is positive infinity return 1, if number is negative
  * infinity return -1, otherwise return 0.
  */
-TRIO_PUBLIC
-int trio_isinf(double number);
+TRIO_PUBLIC int trio_isinf(double number);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* __TRIO_NAN_H__ */
+#endif /* TRIO_NAN_H */
