@@ -4,6 +4,7 @@
  * daniel@veillard.com
  */
 
+#define IN_LIBXML
 #include "libxml.h"
 
 #include <string.h>
@@ -653,6 +654,8 @@ xmlMemoryDump(void)
 {
     FILE *dump;
 
+    if (debugMaxMemSize == 0)
+	return;
     dump = fopen(".memdump", "w");
     if (dump == NULL)
 	xmlMemoryDumpFile = stderr;
